import React from 'react';
import { storiesOf } from '@storybook/react';
import { withKnobs, boolean } from '@storybook/addon-knobs';
import Tour from '../Tour';
import Button from '../Button';
var targets = React.createElement(React.Fragment, null, React.createElement("div", {
  id: "one",
  style: {
    position: 'absolute',
    left: 20,
    top: 20,
    background: 'magenta',
    width: 40,
    height: 40
  }
}), React.createElement(Button, {
  id: "two",
  style: {
    position: 'relative',
    left: 200
  }
}, "I am a button!"), React.createElement("div", {
  id: "three",
  style: {
    position: 'absolute',
    left: 20,
    top: 1800,
    background: 'orange',
    width: 40,
    height: 40
  }
}));
var steps = {
  default: function _default() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#two',
      movingTarget: true,
      title: 'Interaction',
      description: 'You can interact with the elements being highlighted.'
    }];
  },
  scroll: function scroll() {
    return [{
      selector: '#one',
      title: 'Welcome To The Tour',
      description: 'Use this component to point out new or important features.'
    }, {
      selector: '#three',
      description: 'You can scroll to ofscreen elements'
    }];
  }
};
storiesOf('Pattern|Tour', module).add('default', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.default()
  }));
}).add('no mask', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.default(),
    disableMask: true
  }));
}).addDecorator(withKnobs).add('with scrolling', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.scroll(),
    disableAutoScroll: boolean('disable auto scroll', false),
    disableSmoothScroll: boolean('disable smooth scroll', false)
  }));
}).add('hide buttons', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    steps: steps.default(),
    hidePrev: true,
    hideNext: true
  }));
}).add('with flip', function () {
  return React.createElement(React.Fragment, null, targets, React.createElement(Tour, {
    enableFlip: true,
    steps: steps.default(),
    flippedTitle: 'Flipped Title',
    flippedDescription: 'Secondary description on the back side of the card. Currently, this is the same for all steps'
  }));
});